/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.jclouds.abiquo.monitor.functions;

import static com.google.common.base.Preconditions.checkNotNull;

import javax.annotation.Resource;

import org.jclouds.abiquo.domain.cloud.VirtualMachine;
import org.jclouds.abiquo.monitor.MonitorStatus;
import org.jclouds.logging.Logger;

import com.abiquo.server.core.cloud.VirtualMachineState;
import com.google.common.base.Function;
import com.google.inject.Singleton;

/**
 * This class takes care of monitoring the a deploy of a {@link VirtualMachine}.
 * 
 * @author Serafin Sedano
 * @see MonitoringService
 */
@Singleton
public class VirtualMachineDeployMonitor implements Function<VirtualMachine, MonitorStatus> {
   @Resource
   private Logger logger = Logger.NULL;

   @Override
   public MonitorStatus apply(final VirtualMachine virtualMachine) {
      checkNotNull(virtualMachine, "virtualMachine");

      try {
         VirtualMachineState state = virtualMachine.getState();

         switch (state) {
            case NOT_ALLOCATED:
            case UNKNOWN:
               return MonitorStatus.FAILED;
            case ON:
               return MonitorStatus.DONE;
            default:
               return MonitorStatus.CONTINUE;
         }
      } catch (Exception ex) {
         logger.warn(ex, "exception thrown while monitoring %s on %s, returning CONTINUE", virtualMachine, getClass()
               .getName());

         return MonitorStatus.CONTINUE;
      }
   }
}
